{
 "cells": [
  {
   "cell_type": "code",
   "execution_count": 44,
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-12-02T06:27:08.222925Z",
     "start_time": "2021-12-02T06:27:07.668373Z"
    }
   },
   "outputs": [],
   "source": [
    "import numpy as np # linear algebra\n",
    "import pandas as pd # data processing, CSV file I/O (e.g. pd.read_csv)\n",
    "import json\n",
    "import cx_Oracle\n",
    "import os\n",
    "import pandas as pd\n",
    "\n",
    "\n",
    "os.environ['TNS_ADMIN'] = '/home/opc/adj_esportsdb'"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 45,
   "metadata": {},
   "outputs": [],
   "source": [
    "import os\n",
    "\n",
    "os.environ['PATH']='/home/ubuntu/miniconda3/bin:$PATH'"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-12-02T06:27:26.871909Z",
     "start_time": "2021-12-02T06:27:08.224431Z"
    }
   },
   "outputs": [],
   "source": [
    "!pip install simplejson\n",
    "!pip install dataprep\n",
    "!pip install dask\n",
    "!pip install pandas_profiling\n",
    "## install packages\n",
    "!pip install -q scikit-learn\n",
    "!pip install -U setuptools wheel\n",
    "!pip install -U \"mxnet<2.0.0\"\n",
    "!pip install autogluon"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 47,
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-12-02T06:27:26.925982Z",
     "start_time": "2021-12-02T06:27:26.874624Z"
    }
   },
   "outputs": [],
   "source": [
    "import cx_Oracle\n",
    "import yaml\n",
    "import os\n",
    "from pathlib import Path\n",
    "home = str(Path.home())\n",
    "\n",
    "def process_yaml():\n",
    "\twith open(\"../config.yaml\") as file:\n",
    "\t\treturn yaml.safe_load(file)\n",
    "\n",
    "\n",
    "class OracleJSONDatabaseConnection:\n",
    "    def __init__(self, data=process_yaml()):\n",
    "        # wallet location (default is HOME/wallets/wallet_X)\n",
    "        os.environ['TNS_ADMIN'] = '{}/{}'.format(home, process_yaml()['WALLET_DIR'])\n",
    "        print(os.environ['TNS_ADMIN'])\n",
    "        self.pool = cx_Oracle.SessionPool(data['db']['username'], data['db']['password'], data['db']['dsn'],\n",
    "            min=1, max=4, increment=1, threaded=True,\n",
    "            getmode=cx_Oracle.SPOOL_ATTRVAL_WAIT\n",
    "        )\n",
    "        print('Connection successful.')\n",
    "\n",
    "\n",
    "\n",
    "    def close_pool(self):\n",
    "        self.pool.close()\n",
    "        print('Connection pool closed.')\n",
    "\n",
    "\n",
    "\n",
    "    def insert(self, collection_name, json_object_to_insert):\n",
    "        connection = self.pool.acquire()\n",
    "        connection.autocommit = True\n",
    "        soda = connection.getSodaDatabase()\n",
    "        x_collection = soda.createCollection(collection_name)\n",
    "\n",
    "        try:\n",
    "            x_collection.insertOne(json_object_to_insert)\n",
    "            print('[DBG] INSERT {} OK'.format(json_object_to_insert))\n",
    "        except cx_Oracle.IntegrityError:\n",
    "            print('[DBG] INSERT {} ERR'.format(json_object_to_insert))\n",
    "            return 0\n",
    "        self.pool.release(connection)\n",
    "        return 1\n",
    "\n",
    "\n",
    "\n",
    "    def delete(self, collection_name, on_column, on_value):\n",
    "        connection = self.pool.acquire()\n",
    "        soda = connection.getSodaDatabase()\n",
    "        x_collection = soda.createCollection(collection_name)\n",
    "        qbe = {on_column: on_value}\n",
    "        x_collection.find().filter(qbe).remove()\n",
    "        self.pool.release(connection)\n",
    "\n",
    "\n",
    "\n",
    "    def get_connection(self):\n",
    "        return self.pool.acquire() \n",
    "\n",
    "\n",
    "\n",
    "    def close_connection(self, conn_object):\n",
    "        self.pool.release(conn_object)\n",
    "\n",
    "\n",
    "\n",
    "    def get_collection_names(self):\n",
    "        connection = self.pool.acquire()\n",
    "        returning_object = connection.getSodaDatabase().getCollectionNames(startName=None, limit=0)\n",
    "        self.pool.release(connection)\n",
    "        return returning_object\n",
    "\n",
    "\n",
    "\n",
    "    def open_collection(self, collection_name):\n",
    "        connection = self.pool.acquire()\n",
    "        returning_object = self.pool.acquire().getSodaDatabase().openCollection(collection_name)\n",
    "        self.pool.release(connection)\n",
    "        return returning_object\n",
    "\n",
    "\n",
    "\n",
    "def test_class():\n",
    "    object = OracleJSONDatabaseConnection()\n",
    "    print(object.pool)\n",
    "    object.close_pool()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 49,
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-12-02T06:27:37.040915Z",
     "start_time": "2021-12-02T06:27:26.931623Z"
    }
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "/home/ubuntu/wallets/Wallet_eSportsDB\n",
      "Connection successful.\n",
      "['1v1_model', 'match', 'match_detail', 'matchups', 'predictor', 'predictor_liveclient', 'summoner']\n"
     ]
    }
   ],
   "source": [
    "db = OracleJSONDatabaseConnection()\n",
    "print(db.get_collection_names())"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 50,
   "metadata": {},
   "outputs": [],
   "source": [
    "# monkeypatch using faster simplejson module\n",
    "import simplejson\n",
    "pd.io.json._json.loads = lambda s, *a, **kw: simplejson.loads(s)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 51,
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-12-02T06:27:49.061009Z",
     "start_time": "2021-12-02T06:27:37.042207Z"
    }
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Data length: 500001\n"
     ]
    }
   ],
   "source": [
    "data = db.open_collection('predictor_liveclient')\n",
    "all_data = list()\n",
    "i = 0\n",
    "for doc in data.find().getCursor():\n",
    "    content = doc.getContent()\n",
    "    all_data.append(content)\n",
    "    i+= 1\n",
    "    if i > 500000:\n",
    "        break\n",
    "\n",
    "print('Data length: {}'.format(len(all_data)))"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 52,
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-12-02T06:27:55.352548Z",
     "start_time": "2021-12-02T06:27:49.063059Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "<div>\n",
       "<style scoped>\n",
       "    .dataframe tbody tr th:only-of-type {\n",
       "        vertical-align: middle;\n",
       "    }\n",
       "\n",
       "    .dataframe tbody tr th {\n",
       "        vertical-align: top;\n",
       "    }\n",
       "\n",
       "    .dataframe thead th {\n",
       "        text-align: right;\n",
       "    }\n",
       "</style>\n",
       "<table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>winner</th>\n",
       "      <th>magicResist</th>\n",
       "      <th>healthRegenRate</th>\n",
       "      <th>spellVamp</th>\n",
       "      <th>timestamp</th>\n",
       "      <th>bonusArmorPenetrationPercent</th>\n",
       "      <th>bonusMagicPenetrationPercent</th>\n",
       "      <th>maxHealth</th>\n",
       "      <th>identifier</th>\n",
       "      <th>moveSpeed</th>\n",
       "      <th>...</th>\n",
       "      <th>cooldownReduction</th>\n",
       "      <th>resourceValue</th>\n",
       "      <th>magicPenetrationFlat</th>\n",
       "      <th>attackSpeed</th>\n",
       "      <th>currentHealth</th>\n",
       "      <th>armor</th>\n",
       "      <th>magicPenetrationPercent</th>\n",
       "      <th>armorPenetrationFlat</th>\n",
       "      <th>resourceMax</th>\n",
       "      <th>resourceRegenRate</th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>0</th>\n",
       "      <td>1</td>\n",
       "      <td>30</td>\n",
       "      <td>11</td>\n",
       "      <td>0</td>\n",
       "      <td>60025</td>\n",
       "      <td>0</td>\n",
       "      <td>0</td>\n",
       "      <td>520</td>\n",
       "      <td>BR1_2267584388_5</td>\n",
       "      <td>697</td>\n",
       "      <td>...</td>\n",
       "      <td>0</td>\n",
       "      <td>469</td>\n",
       "      <td>0</td>\n",
       "      <td>100</td>\n",
       "      <td>520</td>\n",
       "      <td>28</td>\n",
       "      <td>0</td>\n",
       "      <td>0</td>\n",
       "      <td>469</td>\n",
       "      <td>16</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1</th>\n",
       "      <td>0</td>\n",
       "      <td>32</td>\n",
       "      <td>17</td>\n",
       "      <td>0</td>\n",
       "      <td>60025</td>\n",
       "      <td>0</td>\n",
       "      <td>0</td>\n",
       "      <td>660</td>\n",
       "      <td>BR1_2267584388_6</td>\n",
       "      <td>335</td>\n",
       "      <td>...</td>\n",
       "      <td>0</td>\n",
       "      <td>350</td>\n",
       "      <td>0</td>\n",
       "      <td>110</td>\n",
       "      <td>660</td>\n",
       "      <td>42</td>\n",
       "      <td>0</td>\n",
       "      <td>0</td>\n",
       "      <td>350</td>\n",
       "      <td>16</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2</th>\n",
       "      <td>0</td>\n",
       "      <td>30</td>\n",
       "      <td>11</td>\n",
       "      <td>0</td>\n",
       "      <td>60025</td>\n",
       "      <td>0</td>\n",
       "      <td>0</td>\n",
       "      <td>560</td>\n",
       "      <td>BR1_2267584388_7</td>\n",
       "      <td>340</td>\n",
       "      <td>...</td>\n",
       "      <td>0</td>\n",
       "      <td>340</td>\n",
       "      <td>0</td>\n",
       "      <td>100</td>\n",
       "      <td>560</td>\n",
       "      <td>31</td>\n",
       "      <td>0</td>\n",
       "      <td>0</td>\n",
       "      <td>340</td>\n",
       "      <td>22</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>3</th>\n",
       "      <td>0</td>\n",
       "      <td>32</td>\n",
       "      <td>14</td>\n",
       "      <td>0</td>\n",
       "      <td>60025</td>\n",
       "      <td>0</td>\n",
       "      <td>0</td>\n",
       "      <td>584</td>\n",
       "      <td>BR1_2267584388_8</td>\n",
       "      <td>345</td>\n",
       "      <td>...</td>\n",
       "      <td>0</td>\n",
       "      <td>180</td>\n",
       "      <td>0</td>\n",
       "      <td>100</td>\n",
       "      <td>584</td>\n",
       "      <td>38</td>\n",
       "      <td>0</td>\n",
       "      <td>0</td>\n",
       "      <td>200</td>\n",
       "      <td>100</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>4</th>\n",
       "      <td>0</td>\n",
       "      <td>30</td>\n",
       "      <td>7</td>\n",
       "      <td>0</td>\n",
       "      <td>60025</td>\n",
       "      <td>0</td>\n",
       "      <td>0</td>\n",
       "      <td>680</td>\n",
       "      <td>BR1_2267584388_9</td>\n",
       "      <td>335</td>\n",
       "      <td>...</td>\n",
       "      <td>0</td>\n",
       "      <td>344</td>\n",
       "      <td>0</td>\n",
       "      <td>110</td>\n",
       "      <td>592</td>\n",
       "      <td>34</td>\n",
       "      <td>0</td>\n",
       "      <td>0</td>\n",
       "      <td>344</td>\n",
       "      <td>16</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table>\n",
       "<p>5 rows × 24 columns</p>\n",
       "</div>"
      ],
      "text/plain": [
       "   winner  magicResist  healthRegenRate  spellVamp  timestamp  \\\n",
       "0       1           30               11          0      60025   \n",
       "1       0           32               17          0      60025   \n",
       "2       0           30               11          0      60025   \n",
       "3       0           32               14          0      60025   \n",
       "4       0           30                7          0      60025   \n",
       "\n",
       "   bonusArmorPenetrationPercent  bonusMagicPenetrationPercent  maxHealth  \\\n",
       "0                             0                             0        520   \n",
       "1                             0                             0        660   \n",
       "2                             0                             0        560   \n",
       "3                             0                             0        584   \n",
       "4                             0                             0        680   \n",
       "\n",
       "         identifier  moveSpeed  ...  cooldownReduction  resourceValue  \\\n",
       "0  BR1_2267584388_5        697  ...                  0            469   \n",
       "1  BR1_2267584388_6        335  ...                  0            350   \n",
       "2  BR1_2267584388_7        340  ...                  0            340   \n",
       "3  BR1_2267584388_8        345  ...                  0            180   \n",
       "4  BR1_2267584388_9        335  ...                  0            344   \n",
       "\n",
       "   magicPenetrationFlat  attackSpeed  currentHealth  armor  \\\n",
       "0                     0          100            520     28   \n",
       "1                     0          110            660     42   \n",
       "2                     0          100            560     31   \n",
       "3                     0          100            584     38   \n",
       "4                     0          110            592     34   \n",
       "\n",
       "   magicPenetrationPercent  armorPenetrationFlat  resourceMax  \\\n",
       "0                        0                     0          469   \n",
       "1                        0                     0          350   \n",
       "2                        0                     0          340   \n",
       "3                        0                     0          200   \n",
       "4                        0                     0          344   \n",
       "\n",
       "   resourceRegenRate  \n",
       "0                 16  \n",
       "1                 16  \n",
       "2                 22  \n",
       "3                100  \n",
       "4                 16  \n",
       "\n",
       "[5 rows x 24 columns]"
      ]
     },
     "execution_count": 52,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "df = pd.read_json(json.dumps(all_data), orient='records')\n",
    "\n",
    "df.head(5)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 25,
   "metadata": {},
   "outputs": [],
   "source": [
    "df = df.fillna(0)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 26,
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-12-02T06:27:55.516270Z",
     "start_time": "2021-12-02T06:27:55.354199Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "<div>\n",
       "<style scoped>\n",
       "    .dataframe tbody tr th:only-of-type {\n",
       "        vertical-align: middle;\n",
       "    }\n",
       "\n",
       "    .dataframe tbody tr th {\n",
       "        vertical-align: top;\n",
       "    }\n",
       "\n",
       "    .dataframe thead th {\n",
       "        text-align: right;\n",
       "    }\n",
       "</style>\n",
       "<table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>winner</th>\n",
       "      <th>magicResist</th>\n",
       "      <th>healthRegenRate</th>\n",
       "      <th>spellVamp</th>\n",
       "      <th>timestamp</th>\n",
       "      <th>bonusArmorPenetrationPercent</th>\n",
       "      <th>bonusMagicPenetrationPercent</th>\n",
       "      <th>maxHealth</th>\n",
       "      <th>moveSpeed</th>\n",
       "      <th>attackDamage</th>\n",
       "      <th>...</th>\n",
       "      <th>cooldownReduction</th>\n",
       "      <th>resourceValue</th>\n",
       "      <th>magicPenetrationFlat</th>\n",
       "      <th>attackSpeed</th>\n",
       "      <th>currentHealth</th>\n",
       "      <th>armor</th>\n",
       "      <th>magicPenetrationPercent</th>\n",
       "      <th>armorPenetrationFlat</th>\n",
       "      <th>resourceMax</th>\n",
       "      <th>resourceRegenRate</th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>count</th>\n",
       "      <td>500001.000000</td>\n",
       "      <td>500001.000000</td>\n",
       "      <td>500001.000000</td>\n",
       "      <td>500001.000000</td>\n",
       "      <td>5.000010e+05</td>\n",
       "      <td>500001.0</td>\n",
       "      <td>500001.0</td>\n",
       "      <td>500001.000000</td>\n",
       "      <td>500001.000000</td>\n",
       "      <td>500001.000000</td>\n",
       "      <td>...</td>\n",
       "      <td>500001.0</td>\n",
       "      <td>500001.000000</td>\n",
       "      <td>500001.000000</td>\n",
       "      <td>500001.000000</td>\n",
       "      <td>500001.000000</td>\n",
       "      <td>500001.000000</td>\n",
       "      <td>500001.000000</td>\n",
       "      <td>500001.0</td>\n",
       "      <td>500001.000000</td>\n",
       "      <td>500001.00000</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>mean</th>\n",
       "      <td>0.499969</td>\n",
       "      <td>45.202852</td>\n",
       "      <td>42.668093</td>\n",
       "      <td>0.054268</td>\n",
       "      <td>8.641028e+05</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>1373.862534</td>\n",
       "      <td>382.182052</td>\n",
       "      <td>122.361233</td>\n",
       "      <td>...</td>\n",
       "      <td>0.0</td>\n",
       "      <td>690.072270</td>\n",
       "      <td>2.247516</td>\n",
       "      <td>141.004362</td>\n",
       "      <td>1018.197318</td>\n",
       "      <td>69.115016</td>\n",
       "      <td>0.565651</td>\n",
       "      <td>0.0</td>\n",
       "      <td>879.129072</td>\n",
       "      <td>42.20194</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>std</th>\n",
       "      <td>0.500000</td>\n",
       "      <td>21.270119</td>\n",
       "      <td>92.360539</td>\n",
       "      <td>0.985789</td>\n",
       "      <td>5.588095e+05</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>619.323108</td>\n",
       "      <td>60.230610</td>\n",
       "      <td>75.520146</td>\n",
       "      <td>...</td>\n",
       "      <td>0.0</td>\n",
       "      <td>1265.138271</td>\n",
       "      <td>6.925615</td>\n",
       "      <td>44.513022</td>\n",
       "      <td>671.986160</td>\n",
       "      <td>38.627498</td>\n",
       "      <td>3.703696</td>\n",
       "      <td>0.0</td>\n",
       "      <td>1294.995514</td>\n",
       "      <td>49.54758</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>min</th>\n",
       "      <td>0.000000</td>\n",
       "      <td>-10.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>0.000000e+00</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>340.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>1.000000</td>\n",
       "      <td>...</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>50.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>-14.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>0.00000</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>25%</th>\n",
       "      <td>0.000000</td>\n",
       "      <td>33.000000</td>\n",
       "      <td>16.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>4.200960e+05</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>889.000000</td>\n",
       "      <td>345.000000</td>\n",
       "      <td>73.000000</td>\n",
       "      <td>...</td>\n",
       "      <td>0.0</td>\n",
       "      <td>245.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>112.000000</td>\n",
       "      <td>562.000000</td>\n",
       "      <td>45.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>0.0</td>\n",
       "      <td>400.000000</td>\n",
       "      <td>17.00000</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>50%</th>\n",
       "      <td>0.000000</td>\n",
       "      <td>38.000000</td>\n",
       "      <td>23.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>8.402240e+05</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>1291.000000</td>\n",
       "      <td>375.000000</td>\n",
       "      <td>93.000000</td>\n",
       "      <td>...</td>\n",
       "      <td>0.0</td>\n",
       "      <td>441.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>125.000000</td>\n",
       "      <td>946.000000</td>\n",
       "      <td>59.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>0.0</td>\n",
       "      <td>636.000000</td>\n",
       "      <td>26.00000</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>75%</th>\n",
       "      <td>1.000000</td>\n",
       "      <td>47.000000</td>\n",
       "      <td>35.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>1.260431e+06</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>1720.000000</td>\n",
       "      <td>395.000000</td>\n",
       "      <td>154.000000</td>\n",
       "      <td>...</td>\n",
       "      <td>0.0</td>\n",
       "      <td>743.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>154.000000</td>\n",
       "      <td>1437.000000</td>\n",
       "      <td>81.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>0.0</td>\n",
       "      <td>948.000000</td>\n",
       "      <td>48.00000</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>max</th>\n",
       "      <td>1.000000</td>\n",
       "      <td>492.000000</td>\n",
       "      <td>5682.000000</td>\n",
       "      <td>37.000000</td>\n",
       "      <td>3.147362e+06</td>\n",
       "      <td>0.0</td>\n",
       "      <td>0.0</td>\n",
       "      <td>7019.000000</td>\n",
       "      <td>1224.000000</td>\n",
       "      <td>936.000000</td>\n",
       "      <td>...</td>\n",
       "      <td>0.0</td>\n",
       "      <td>10000.000000</td>\n",
       "      <td>50.000000</td>\n",
       "      <td>621.000000</td>\n",
       "      <td>6921.000000</td>\n",
       "      <td>847.000000</td>\n",
       "      <td>48.000000</td>\n",
       "      <td>0.0</td>\n",
       "      <td>10000.000000</td>\n",
       "      <td>694.00000</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table>\n",
       "<p>8 rows × 23 columns</p>\n",
       "</div>"
      ],
      "text/plain": [
       "              winner    magicResist  healthRegenRate      spellVamp  \\\n",
       "count  500001.000000  500001.000000    500001.000000  500001.000000   \n",
       "mean        0.499969      45.202852        42.668093       0.054268   \n",
       "std         0.500000      21.270119        92.360539       0.985789   \n",
       "min         0.000000     -10.000000         0.000000       0.000000   \n",
       "25%         0.000000      33.000000        16.000000       0.000000   \n",
       "50%         0.000000      38.000000        23.000000       0.000000   \n",
       "75%         1.000000      47.000000        35.000000       0.000000   \n",
       "max         1.000000     492.000000      5682.000000      37.000000   \n",
       "\n",
       "          timestamp  bonusArmorPenetrationPercent  \\\n",
       "count  5.000010e+05                      500001.0   \n",
       "mean   8.641028e+05                           0.0   \n",
       "std    5.588095e+05                           0.0   \n",
       "min    0.000000e+00                           0.0   \n",
       "25%    4.200960e+05                           0.0   \n",
       "50%    8.402240e+05                           0.0   \n",
       "75%    1.260431e+06                           0.0   \n",
       "max    3.147362e+06                           0.0   \n",
       "\n",
       "       bonusMagicPenetrationPercent      maxHealth      moveSpeed  \\\n",
       "count                      500001.0  500001.000000  500001.000000   \n",
       "mean                            0.0    1373.862534     382.182052   \n",
       "std                             0.0     619.323108      60.230610   \n",
       "min                             0.0     340.000000       0.000000   \n",
       "25%                             0.0     889.000000     345.000000   \n",
       "50%                             0.0    1291.000000     375.000000   \n",
       "75%                             0.0    1720.000000     395.000000   \n",
       "max                             0.0    7019.000000    1224.000000   \n",
       "\n",
       "        attackDamage  ...  cooldownReduction  resourceValue  \\\n",
       "count  500001.000000  ...           500001.0  500001.000000   \n",
       "mean      122.361233  ...                0.0     690.072270   \n",
       "std        75.520146  ...                0.0    1265.138271   \n",
       "min         1.000000  ...                0.0       0.000000   \n",
       "25%        73.000000  ...                0.0     245.000000   \n",
       "50%        93.000000  ...                0.0     441.000000   \n",
       "75%       154.000000  ...                0.0     743.000000   \n",
       "max       936.000000  ...                0.0   10000.000000   \n",
       "\n",
       "       magicPenetrationFlat    attackSpeed  currentHealth          armor  \\\n",
       "count         500001.000000  500001.000000  500001.000000  500001.000000   \n",
       "mean               2.247516     141.004362    1018.197318      69.115016   \n",
       "std                6.925615      44.513022     671.986160      38.627498   \n",
       "min                0.000000      50.000000       0.000000     -14.000000   \n",
       "25%                0.000000     112.000000     562.000000      45.000000   \n",
       "50%                0.000000     125.000000     946.000000      59.000000   \n",
       "75%                0.000000     154.000000    1437.000000      81.000000   \n",
       "max               50.000000     621.000000    6921.000000     847.000000   \n",
       "\n",
       "       magicPenetrationPercent  armorPenetrationFlat    resourceMax  \\\n",
       "count            500001.000000              500001.0  500001.000000   \n",
       "mean                  0.565651                   0.0     879.129072   \n",
       "std                   3.703696                   0.0    1294.995514   \n",
       "min                   0.000000                   0.0       0.000000   \n",
       "25%                   0.000000                   0.0     400.000000   \n",
       "50%                   0.000000                   0.0     636.000000   \n",
       "75%                   0.000000                   0.0     948.000000   \n",
       "max                  48.000000                   0.0   10000.000000   \n",
       "\n",
       "       resourceRegenRate  \n",
       "count       500001.00000  \n",
       "mean            42.20194  \n",
       "std             49.54758  \n",
       "min              0.00000  \n",
       "25%             17.00000  \n",
       "50%             26.00000  \n",
       "75%             48.00000  \n",
       "max            694.00000  \n",
       "\n",
       "[8 rows x 23 columns]"
      ]
     },
     "execution_count": 26,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "df.describe()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 27,
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-12-02T06:27:58.629448Z",
     "start_time": "2021-12-02T06:27:55.518022Z"
    }
   },
   "outputs": [],
   "source": [
    "from pandas_profiling import ProfileReport"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 28,
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-12-02T06:29:44.757906Z",
     "start_time": "2021-12-02T06:27:58.631099Z"
    }
   },
   "outputs": [],
   "source": [
    "#report = ProfileReport(df)\n",
    "#report #uncomment to display all."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 29,
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-12-02T06:29:46.055749Z",
     "start_time": "2021-12-02T06:29:44.759876Z"
    }
   },
   "outputs": [],
   "source": [
    "from autogluon.tabular import TabularPredictor, TabularDataset"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 30,
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-12-02T06:36:36.194278Z",
     "start_time": "2021-12-02T06:36:36.096513Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "<div>\n",
       "<style scoped>\n",
       "    .dataframe tbody tr th:only-of-type {\n",
       "        vertical-align: middle;\n",
       "    }\n",
       "\n",
       "    .dataframe tbody tr th {\n",
       "        vertical-align: top;\n",
       "    }\n",
       "\n",
       "    .dataframe thead th {\n",
       "        text-align: right;\n",
       "    }\n",
       "</style>\n",
       "<table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>winner</th>\n",
       "      <th>magicResist</th>\n",
       "      <th>healthRegenRate</th>\n",
       "      <th>spellVamp</th>\n",
       "      <th>timestamp</th>\n",
       "      <th>maxHealth</th>\n",
       "      <th>moveSpeed</th>\n",
       "      <th>attackDamage</th>\n",
       "      <th>armorPenetrationPercent</th>\n",
       "      <th>lifesteal</th>\n",
       "      <th>abilityPower</th>\n",
       "      <th>resourceValue</th>\n",
       "      <th>magicPenetrationFlat</th>\n",
       "      <th>attackSpeed</th>\n",
       "      <th>currentHealth</th>\n",
       "      <th>armor</th>\n",
       "      <th>magicPenetrationPercent</th>\n",
       "      <th>resourceMax</th>\n",
       "      <th>resourceRegenRate</th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>461559</th>\n",
       "      <td>0</td>\n",
       "      <td>30</td>\n",
       "      <td>11</td>\n",
       "      <td>0</td>\n",
       "      <td>180049</td>\n",
       "      <td>662</td>\n",
       "      <td>340</td>\n",
       "      <td>57</td>\n",
       "      <td>0</td>\n",
       "      <td>0</td>\n",
       "      <td>33</td>\n",
       "      <td>270</td>\n",
       "      <td>0</td>\n",
       "      <td>100</td>\n",
       "      <td>496</td>\n",
       "      <td>30</td>\n",
       "      <td>0</td>\n",
       "      <td>549</td>\n",
       "      <td>17</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>38055</th>\n",
       "      <td>1</td>\n",
       "      <td>66</td>\n",
       "      <td>136</td>\n",
       "      <td>0</td>\n",
       "      <td>600233</td>\n",
       "      <td>1265</td>\n",
       "      <td>392</td>\n",
       "      <td>186</td>\n",
       "      <td>20</td>\n",
       "      <td>0</td>\n",
       "      <td>0</td>\n",
       "      <td>583</td>\n",
       "      <td>0</td>\n",
       "      <td>115</td>\n",
       "      <td>720</td>\n",
       "      <td>59</td>\n",
       "      <td>0</td>\n",
       "      <td>650</td>\n",
       "      <td>80</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>46195</th>\n",
       "      <td>1</td>\n",
       "      <td>31</td>\n",
       "      <td>13</td>\n",
       "      <td>0</td>\n",
       "      <td>360086</td>\n",
       "      <td>759</td>\n",
       "      <td>335</td>\n",
       "      <td>58</td>\n",
       "      <td>0</td>\n",
       "      <td>0</td>\n",
       "      <td>26</td>\n",
       "      <td>290</td>\n",
       "      <td>0</td>\n",
       "      <td>105</td>\n",
       "      <td>440</td>\n",
       "      <td>40</td>\n",
       "      <td>0</td>\n",
       "      <td>712</td>\n",
       "      <td>42</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>454169</th>\n",
       "      <td>0</td>\n",
       "      <td>33</td>\n",
       "      <td>20</td>\n",
       "      <td>0</td>\n",
       "      <td>960241</td>\n",
       "      <td>1144</td>\n",
       "      <td>390</td>\n",
       "      <td>67</td>\n",
       "      <td>0</td>\n",
       "      <td>0</td>\n",
       "      <td>112</td>\n",
       "      <td>910</td>\n",
       "      <td>0</td>\n",
       "      <td>115</td>\n",
       "      <td>1144</td>\n",
       "      <td>53</td>\n",
       "      <td>0</td>\n",
       "      <td>1120</td>\n",
       "      <td>97</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>373019</th>\n",
       "      <td>1</td>\n",
       "      <td>44</td>\n",
       "      <td>95</td>\n",
       "      <td>0</td>\n",
       "      <td>1020349</td>\n",
       "      <td>2096</td>\n",
       "      <td>483</td>\n",
       "      <td>212</td>\n",
       "      <td>0</td>\n",
       "      <td>0</td>\n",
       "      <td>0</td>\n",
       "      <td>0</td>\n",
       "      <td>0</td>\n",
       "      <td>124</td>\n",
       "      <td>1428</td>\n",
       "      <td>130</td>\n",
       "      <td>0</td>\n",
       "      <td>0</td>\n",
       "      <td>0</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table>\n",
       "</div>"
      ],
      "text/plain": [
       "        winner  magicResist  healthRegenRate  spellVamp  timestamp  maxHealth  \\\n",
       "461559       0           30               11          0     180049        662   \n",
       "38055        1           66              136          0     600233       1265   \n",
       "46195        1           31               13          0     360086        759   \n",
       "454169       0           33               20          0     960241       1144   \n",
       "373019       1           44               95          0    1020349       2096   \n",
       "\n",
       "        moveSpeed  attackDamage  armorPenetrationPercent  lifesteal  \\\n",
       "461559        340            57                        0          0   \n",
       "38055         392           186                       20          0   \n",
       "46195         335            58                        0          0   \n",
       "454169        390            67                        0          0   \n",
       "373019        483           212                        0          0   \n",
       "\n",
       "        abilityPower  resourceValue  magicPenetrationFlat  attackSpeed  \\\n",
       "461559            33            270                     0          100   \n",
       "38055              0            583                     0          115   \n",
       "46195             26            290                     0          105   \n",
       "454169           112            910                     0          115   \n",
       "373019             0              0                     0          124   \n",
       "\n",
       "        currentHealth  armor  magicPenetrationPercent  resourceMax  \\\n",
       "461559            496     30                        0          549   \n",
       "38055             720     59                        0          650   \n",
       "46195             440     40                        0          712   \n",
       "454169           1144     53                        0         1120   \n",
       "373019           1428    130                        0            0   \n",
       "\n",
       "        resourceRegenRate  \n",
       "461559                 17  \n",
       "38055                  80  \n",
       "46195                  42  \n",
       "454169                 97  \n",
       "373019                  0  "
      ]
     },
     "execution_count": 30,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "df = TabularDataset(df)\n",
    "\n",
    "# drop columns we don't want (constant values + identifier)\n",
    "df = df.drop(columns=['bonusArmorPenetrationPercent', 'bonusMagicPenetrationPercent',\n",
    "    'identifier', 'cooldownReduction', 'armorPenetrationFlat'])\n",
    "\n",
    "train = df.sample(frac=0.8,random_state=200) #random state is a seed value\n",
    "test = df.drop(train.index)\n",
    "\n",
    "train.head(5)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 31,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "<div>\n",
       "<style scoped>\n",
       "    .dataframe tbody tr th:only-of-type {\n",
       "        vertical-align: middle;\n",
       "    }\n",
       "\n",
       "    .dataframe tbody tr th {\n",
       "        vertical-align: top;\n",
       "    }\n",
       "\n",
       "    .dataframe thead th {\n",
       "        text-align: right;\n",
       "    }\n",
       "</style>\n",
       "<table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>winner</th>\n",
       "      <th>magicResist</th>\n",
       "      <th>healthRegenRate</th>\n",
       "      <th>spellVamp</th>\n",
       "      <th>timestamp</th>\n",
       "      <th>maxHealth</th>\n",
       "      <th>moveSpeed</th>\n",
       "      <th>attackDamage</th>\n",
       "      <th>armorPenetrationPercent</th>\n",
       "      <th>lifesteal</th>\n",
       "      <th>abilityPower</th>\n",
       "      <th>resourceValue</th>\n",
       "      <th>magicPenetrationFlat</th>\n",
       "      <th>attackSpeed</th>\n",
       "      <th>currentHealth</th>\n",
       "      <th>armor</th>\n",
       "      <th>magicPenetrationPercent</th>\n",
       "      <th>resourceMax</th>\n",
       "      <th>resourceRegenRate</th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>count</th>\n",
       "      <td>500001.000000</td>\n",
       "      <td>500001.000000</td>\n",
       "      <td>500001.000000</td>\n",
       "      <td>500001.000000</td>\n",
       "      <td>5.000010e+05</td>\n",
       "      <td>500001.000000</td>\n",
       "      <td>500001.000000</td>\n",
       "      <td>500001.000000</td>\n",
       "      <td>500001.000000</td>\n",
       "      <td>500001.000000</td>\n",
       "      <td>500001.000000</td>\n",
       "      <td>500001.000000</td>\n",
       "      <td>500001.000000</td>\n",
       "      <td>500001.000000</td>\n",
       "      <td>500001.000000</td>\n",
       "      <td>500001.000000</td>\n",
       "      <td>500001.000000</td>\n",
       "      <td>500001.000000</td>\n",
       "      <td>500001.00000</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>mean</th>\n",
       "      <td>0.499969</td>\n",
       "      <td>45.202852</td>\n",
       "      <td>42.668093</td>\n",
       "      <td>0.054268</td>\n",
       "      <td>8.641028e+05</td>\n",
       "      <td>1373.862534</td>\n",
       "      <td>382.182052</td>\n",
       "      <td>122.361233</td>\n",
       "      <td>1.019892</td>\n",
       "      <td>1.471075</td>\n",
       "      <td>49.147090</td>\n",
       "      <td>690.072270</td>\n",
       "      <td>2.247516</td>\n",
       "      <td>141.004362</td>\n",
       "      <td>1018.197318</td>\n",
       "      <td>69.115016</td>\n",
       "      <td>0.565651</td>\n",
       "      <td>879.129072</td>\n",
       "      <td>42.20194</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>std</th>\n",
       "      <td>0.500000</td>\n",
       "      <td>21.270119</td>\n",
       "      <td>92.360539</td>\n",
       "      <td>0.985789</td>\n",
       "      <td>5.588095e+05</td>\n",
       "      <td>619.323108</td>\n",
       "      <td>60.230610</td>\n",
       "      <td>75.520146</td>\n",
       "      <td>5.082061</td>\n",
       "      <td>4.182162</td>\n",
       "      <td>96.778322</td>\n",
       "      <td>1265.138271</td>\n",
       "      <td>6.925615</td>\n",
       "      <td>44.513022</td>\n",
       "      <td>671.986160</td>\n",
       "      <td>38.627498</td>\n",
       "      <td>3.703696</td>\n",
       "      <td>1294.995514</td>\n",
       "      <td>49.54758</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>min</th>\n",
       "      <td>0.000000</td>\n",
       "      <td>-10.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>0.000000e+00</td>\n",
       "      <td>340.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>1.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>50.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>-14.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>0.00000</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>25%</th>\n",
       "      <td>0.000000</td>\n",
       "      <td>33.000000</td>\n",
       "      <td>16.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>4.200960e+05</td>\n",
       "      <td>889.000000</td>\n",
       "      <td>345.000000</td>\n",
       "      <td>73.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>245.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>112.000000</td>\n",
       "      <td>562.000000</td>\n",
       "      <td>45.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>400.000000</td>\n",
       "      <td>17.00000</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>50%</th>\n",
       "      <td>0.000000</td>\n",
       "      <td>38.000000</td>\n",
       "      <td>23.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>8.402240e+05</td>\n",
       "      <td>1291.000000</td>\n",
       "      <td>375.000000</td>\n",
       "      <td>93.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>441.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>125.000000</td>\n",
       "      <td>946.000000</td>\n",
       "      <td>59.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>636.000000</td>\n",
       "      <td>26.00000</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>75%</th>\n",
       "      <td>1.000000</td>\n",
       "      <td>47.000000</td>\n",
       "      <td>35.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>1.260431e+06</td>\n",
       "      <td>1720.000000</td>\n",
       "      <td>395.000000</td>\n",
       "      <td>154.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>53.000000</td>\n",
       "      <td>743.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>154.000000</td>\n",
       "      <td>1437.000000</td>\n",
       "      <td>81.000000</td>\n",
       "      <td>0.000000</td>\n",
       "      <td>948.000000</td>\n",
       "      <td>48.00000</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>max</th>\n",
       "      <td>1.000000</td>\n",
       "      <td>492.000000</td>\n",
       "      <td>5682.000000</td>\n",
       "      <td>37.000000</td>\n",
       "      <td>3.147362e+06</td>\n",
       "      <td>7019.000000</td>\n",
       "      <td>1224.000000</td>\n",
       "      <td>936.000000</td>\n",
       "      <td>58.000000</td>\n",
       "      <td>125.000000</td>\n",
       "      <td>1260.000000</td>\n",
       "      <td>10000.000000</td>\n",
       "      <td>50.000000</td>\n",
       "      <td>621.000000</td>\n",
       "      <td>6921.000000</td>\n",
       "      <td>847.000000</td>\n",
       "      <td>48.000000</td>\n",
       "      <td>10000.000000</td>\n",
       "      <td>694.00000</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table>\n",
       "</div>"
      ],
      "text/plain": [
       "              winner    magicResist  healthRegenRate      spellVamp  \\\n",
       "count  500001.000000  500001.000000    500001.000000  500001.000000   \n",
       "mean        0.499969      45.202852        42.668093       0.054268   \n",
       "std         0.500000      21.270119        92.360539       0.985789   \n",
       "min         0.000000     -10.000000         0.000000       0.000000   \n",
       "25%         0.000000      33.000000        16.000000       0.000000   \n",
       "50%         0.000000      38.000000        23.000000       0.000000   \n",
       "75%         1.000000      47.000000        35.000000       0.000000   \n",
       "max         1.000000     492.000000      5682.000000      37.000000   \n",
       "\n",
       "          timestamp      maxHealth      moveSpeed   attackDamage  \\\n",
       "count  5.000010e+05  500001.000000  500001.000000  500001.000000   \n",
       "mean   8.641028e+05    1373.862534     382.182052     122.361233   \n",
       "std    5.588095e+05     619.323108      60.230610      75.520146   \n",
       "min    0.000000e+00     340.000000       0.000000       1.000000   \n",
       "25%    4.200960e+05     889.000000     345.000000      73.000000   \n",
       "50%    8.402240e+05    1291.000000     375.000000      93.000000   \n",
       "75%    1.260431e+06    1720.000000     395.000000     154.000000   \n",
       "max    3.147362e+06    7019.000000    1224.000000     936.000000   \n",
       "\n",
       "       armorPenetrationPercent      lifesteal   abilityPower  resourceValue  \\\n",
       "count            500001.000000  500001.000000  500001.000000  500001.000000   \n",
       "mean                  1.019892       1.471075      49.147090     690.072270   \n",
       "std                   5.082061       4.182162      96.778322    1265.138271   \n",
       "min                   0.000000       0.000000       0.000000       0.000000   \n",
       "25%                   0.000000       0.000000       0.000000     245.000000   \n",
       "50%                   0.000000       0.000000       0.000000     441.000000   \n",
       "75%                   0.000000       0.000000      53.000000     743.000000   \n",
       "max                  58.000000     125.000000    1260.000000   10000.000000   \n",
       "\n",
       "       magicPenetrationFlat    attackSpeed  currentHealth          armor  \\\n",
       "count         500001.000000  500001.000000  500001.000000  500001.000000   \n",
       "mean               2.247516     141.004362    1018.197318      69.115016   \n",
       "std                6.925615      44.513022     671.986160      38.627498   \n",
       "min                0.000000      50.000000       0.000000     -14.000000   \n",
       "25%                0.000000     112.000000     562.000000      45.000000   \n",
       "50%                0.000000     125.000000     946.000000      59.000000   \n",
       "75%                0.000000     154.000000    1437.000000      81.000000   \n",
       "max               50.000000     621.000000    6921.000000     847.000000   \n",
       "\n",
       "       magicPenetrationPercent    resourceMax  resourceRegenRate  \n",
       "count            500001.000000  500001.000000       500001.00000  \n",
       "mean                  0.565651     879.129072           42.20194  \n",
       "std                   3.703696    1294.995514           49.54758  \n",
       "min                   0.000000       0.000000            0.00000  \n",
       "25%                   0.000000     400.000000           17.00000  \n",
       "50%                   0.000000     636.000000           26.00000  \n",
       "75%                   0.000000     948.000000           48.00000  \n",
       "max                  48.000000   10000.000000          694.00000  "
      ]
     },
     "execution_count": 31,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "df.describe()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 32,
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-12-02T06:36:39.063380Z",
     "start_time": "2021-12-02T06:36:39.060228Z"
    }
   },
   "outputs": [],
   "source": [
    "label = 'winner'"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 33,
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-12-02T06:58:24.207471Z",
     "start_time": "2021-12-02T06:36:52.653425Z"
    }
   },
   "outputs": [
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "Warning: path already exists! This predictor may overwrite an existing predictor! path=\"./autogluon_trained_models_liveclient_classifier\"\n",
      "Warning: Training may take a very long time because `time_limit` was not specified and `train_data` is large (400001 samples, 64.0 MB).\n",
      "\tConsider setting `time_limit` to ensure training finishes within an expected duration or experiment with a small portion of `train_data` to identify an ideal `presets` and `hyperparameters` configuration.\n",
      "Beginning AutoGluon training ...\n",
      "AutoGluon will save models to \"./autogluon_trained_models_liveclient_classifier/\"\n",
      "AutoGluon Version:  0.3.1\n",
      "Train Data Rows:    400001\n",
      "Train Data Columns: 18\n",
      "Preprocessing data ...\n",
      "AutoGluon infers your prediction problem is: 'binary' (because only two unique label-values observed).\n",
      "\t2 unique label values:  [0, 1]\n",
      "\tIf 'binary' is not the correct problem_type, please manually specify the problem_type argument in fit() (You may specify problem_type as one of: ['binary', 'multiclass', 'regression'])\n",
      "Selected class <--> label mapping:  class 1 = 1, class 0 = 0\n",
      "Using Feature Generators to preprocess the data ...\n",
      "Fitting AutoMLPipelineFeatureGenerator...\n",
      "\tAvailable Memory:                    262455.58 MB\n",
      "\tTrain Data (Original)  Memory Usage: 57.6 MB (0.0% of available memory)\n",
      "\tInferring data type of each feature based on column values. Set feature_metadata_in to manually specify special dtypes of the features.\n",
      "\tStage 1 Generators:\n",
      "\t\tFitting AsTypeFeatureGenerator...\n",
      "\tStage 2 Generators:\n",
      "\t\tFitting FillNaFeatureGenerator...\n",
      "\tStage 3 Generators:\n",
      "\t\tFitting IdentityFeatureGenerator...\n",
      "\tStage 4 Generators:\n",
      "\t\tFitting DropUniqueFeatureGenerator...\n",
      "\tTypes of features in original data (raw dtype, special dtypes):\n",
      "\t\t('int', []) : 18 | ['magicResist', 'healthRegenRate', 'spellVamp', 'timestamp', 'maxHealth', ...]\n",
      "\tTypes of features in processed data (raw dtype, special dtypes):\n",
      "\t\t('int', []) : 18 | ['magicResist', 'healthRegenRate', 'spellVamp', 'timestamp', 'maxHealth', ...]\n",
      "\t0.4s = Fit runtime\n",
      "\t18 features in original data used to generate 18 features in processed data.\n",
      "\tTrain Data (Processed) Memory Usage: 57.6 MB (0.0% of available memory)\n",
      "Data preprocessing and feature engineering runtime = 0.51s ...\n",
      "AutoGluon will gauge predictive performance using evaluation metric: 'accuracy'\n",
      "\tTo change this, specify the eval_metric argument of fit()\n",
      "Automatically generating train/validation split with holdout_frac=0.01, Train Rows: 396000, Val Rows: 4001\n",
      "Fitting 13 L1 models ...\n",
      "Fitting model: KNeighborsUnif ...\n",
      "\t0.5341\t = Validation score   (accuracy)\n",
      "\t0.08s\t = Training   runtime\n",
      "\t40.2s\t = Validation runtime\n",
      "Fitting model: KNeighborsDist ...\n",
      "\t0.5326\t = Validation score   (accuracy)\n",
      "\t0.08s\t = Training   runtime\n",
      "\t39.49s\t = Validation runtime\n",
      "Fitting model: LightGBMXT ...\n",
      "/home/ubuntu/miniconda3/lib/python3.7/site-packages/lightgbm/engine.py:239: UserWarning: 'verbose_eval' argument is deprecated and will be removed in a future release of LightGBM. Pass 'log_evaluation()' callback via 'callbacks' argument instead.\n",
      "  _log_warning(\"'verbose_eval' argument is deprecated and will be removed in a future release of LightGBM. \"\n",
      "\t0.5721\t = Validation score   (accuracy)\n",
      "\t0.72s\t = Training   runtime\n",
      "\t0.01s\t = Validation runtime\n",
      "Fitting model: LightGBM ...\n",
      "/home/ubuntu/miniconda3/lib/python3.7/site-packages/lightgbm/engine.py:239: UserWarning: 'verbose_eval' argument is deprecated and will be removed in a future release of LightGBM. Pass 'log_evaluation()' callback via 'callbacks' argument instead.\n",
      "  _log_warning(\"'verbose_eval' argument is deprecated and will be removed in a future release of LightGBM. \"\n",
      "\t0.5756\t = Validation score   (accuracy)\n",
      "\t0.48s\t = Training   runtime\n",
      "\t0.01s\t = Validation runtime\n",
      "Fitting model: RandomForestGini ...\n",
      "\t0.6768\t = Validation score   (accuracy)\n",
      "\t22.37s\t = Training   runtime\n",
      "\t0.32s\t = Validation runtime\n",
      "Fitting model: RandomForestEntr ...\n",
      "\t0.6771\t = Validation score   (accuracy)\n",
      "\t24.85s\t = Training   runtime\n",
      "\t0.31s\t = Validation runtime\n",
      "Fitting model: CatBoost ...\n",
      "\t0.5659\t = Validation score   (accuracy)\n",
      "\t0.81s\t = Training   runtime\n",
      "\t0.01s\t = Validation runtime\n",
      "Fitting model: ExtraTreesGini ...\n",
      "\t0.6698\t = Validation score   (accuracy)\n",
      "\t11.35s\t = Training   runtime\n",
      "\t0.31s\t = Validation runtime\n",
      "Fitting model: ExtraTreesEntr ...\n",
      "\t0.6733\t = Validation score   (accuracy)\n",
      "\t11.6s\t = Training   runtime\n",
      "\t0.31s\t = Validation runtime\n",
      "Fitting model: NeuralNetFastAI ...\n",
      "\t0.6158\t = Validation score   (accuracy)\n",
      "\t325.65s\t = Training   runtime\n",
      "\t0.05s\t = Validation runtime\n",
      "Fitting model: XGBoost ...\n",
      "\t0.6141\t = Validation score   (accuracy)\n",
      "\t0.97s\t = Training   runtime\n",
      "\t0.03s\t = Validation runtime\n",
      "Fitting model: NeuralNetMXNet ...\n",
      "\t0.6486\t = Validation score   (accuracy)\n",
      "\t793.45s\t = Training   runtime\n",
      "\t0.24s\t = Validation runtime\n",
      "Fitting model: LightGBMLarge ...\n",
      "/home/ubuntu/miniconda3/lib/python3.7/site-packages/lightgbm/engine.py:239: UserWarning: 'verbose_eval' argument is deprecated and will be removed in a future release of LightGBM. Pass 'log_evaluation()' callback via 'callbacks' argument instead.\n",
      "  _log_warning(\"'verbose_eval' argument is deprecated and will be removed in a future release of LightGBM. \"\n",
      "\t0.6228\t = Validation score   (accuracy)\n",
      "\t3.81s\t = Training   runtime\n",
      "\t0.02s\t = Validation runtime\n",
      "Fitting model: WeightedEnsemble_L2 ...\n",
      "\t0.6891\t = Validation score   (accuracy)\n",
      "\t1.36s\t = Training   runtime\n",
      "\t0.01s\t = Validation runtime\n",
      "AutoGluon training complete, total runtime = 1468.14s ...\n",
      "TabularPredictor saved. To load, use: predictor = TabularPredictor.load(\"./autogluon_trained_models_liveclient_classifier/\")\n"
     ]
    }
   ],
   "source": [
    "save_path = './autogluon_trained_models_liveclient_classifier'  # specifies folder to store trained models\n",
    "predictor = TabularPredictor(label=label, path=save_path).fit(train)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 34,
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-12-02T06:58:24.226533Z",
     "start_time": "2021-12-02T06:58:24.210920Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "<div>\n",
       "<style scoped>\n",
       "    .dataframe tbody tr th:only-of-type {\n",
       "        vertical-align: middle;\n",
       "    }\n",
       "\n",
       "    .dataframe tbody tr th {\n",
       "        vertical-align: top;\n",
       "    }\n",
       "\n",
       "    .dataframe thead th {\n",
       "        text-align: right;\n",
       "    }\n",
       "</style>\n",
       "<table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>magicResist</th>\n",
       "      <th>healthRegenRate</th>\n",
       "      <th>spellVamp</th>\n",
       "      <th>timestamp</th>\n",
       "      <th>maxHealth</th>\n",
       "      <th>moveSpeed</th>\n",
       "      <th>attackDamage</th>\n",
       "      <th>armorPenetrationPercent</th>\n",
       "      <th>lifesteal</th>\n",
       "      <th>abilityPower</th>\n",
       "      <th>resourceValue</th>\n",
       "      <th>magicPenetrationFlat</th>\n",
       "      <th>attackSpeed</th>\n",
       "      <th>currentHealth</th>\n",
       "      <th>armor</th>\n",
       "      <th>magicPenetrationPercent</th>\n",
       "      <th>resourceMax</th>\n",
       "      <th>resourceRegenRate</th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>0</th>\n",
       "      <td>32</td>\n",
       "      <td>12</td>\n",
       "      <td>0</td>\n",
       "      <td>660207</td>\n",
       "      <td>1038</td>\n",
       "      <td>370</td>\n",
       "      <td>166</td>\n",
       "      <td>0</td>\n",
       "      <td>4</td>\n",
       "      <td>0</td>\n",
       "      <td>112</td>\n",
       "      <td>0</td>\n",
       "      <td>190</td>\n",
       "      <td>752</td>\n",
       "      <td>51</td>\n",
       "      <td>0</td>\n",
       "      <td>590</td>\n",
       "      <td>17</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2</th>\n",
       "      <td>39</td>\n",
       "      <td>23</td>\n",
       "      <td>0</td>\n",
       "      <td>720219</td>\n",
       "      <td>1215</td>\n",
       "      <td>375</td>\n",
       "      <td>139</td>\n",
       "      <td>0</td>\n",
       "      <td>0</td>\n",
       "      <td>0</td>\n",
       "      <td>599</td>\n",
       "      <td>0</td>\n",
       "      <td>131</td>\n",
       "      <td>1215</td>\n",
       "      <td>86</td>\n",
       "      <td>0</td>\n",
       "      <td>599</td>\n",
       "      <td>23</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>8</th>\n",
       "      <td>118</td>\n",
       "      <td>20</td>\n",
       "      <td>0</td>\n",
       "      <td>720219</td>\n",
       "      <td>1375</td>\n",
       "      <td>208</td>\n",
       "      <td>76</td>\n",
       "      <td>0</td>\n",
       "      <td>0</td>\n",
       "      <td>9</td>\n",
       "      <td>0</td>\n",
       "      <td>0</td>\n",
       "      <td>107</td>\n",
       "      <td>520</td>\n",
       "      <td>122</td>\n",
       "      <td>0</td>\n",
       "      <td>0</td>\n",
       "      <td>0</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>9</th>\n",
       "      <td>88</td>\n",
       "      <td>40</td>\n",
       "      <td>0</td>\n",
       "      <td>1380459</td>\n",
       "      <td>2688</td>\n",
       "      <td>427</td>\n",
       "      <td>101</td>\n",
       "      <td>0</td>\n",
       "      <td>0</td>\n",
       "      <td>0</td>\n",
       "      <td>0</td>\n",
       "      <td>0</td>\n",
       "      <td>117</td>\n",
       "      <td>0</td>\n",
       "      <td>180</td>\n",
       "      <td>0</td>\n",
       "      <td>0</td>\n",
       "      <td>0</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>13</th>\n",
       "      <td>36</td>\n",
       "      <td>22</td>\n",
       "      <td>0</td>\n",
       "      <td>1380459</td>\n",
       "      <td>1449</td>\n",
       "      <td>375</td>\n",
       "      <td>72</td>\n",
       "      <td>0</td>\n",
       "      <td>0</td>\n",
       "      <td>144</td>\n",
       "      <td>1008</td>\n",
       "      <td>0</td>\n",
       "      <td>129</td>\n",
       "      <td>0</td>\n",
       "      <td>71</td>\n",
       "      <td>0</td>\n",
       "      <td>1232</td>\n",
       "      <td>113</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table>\n",
       "</div>"
      ],
      "text/plain": [
       "    magicResist  healthRegenRate  spellVamp  timestamp  maxHealth  moveSpeed  \\\n",
       "0            32               12          0     660207       1038        370   \n",
       "2            39               23          0     720219       1215        375   \n",
       "8           118               20          0     720219       1375        208   \n",
       "9            88               40          0    1380459       2688        427   \n",
       "13           36               22          0    1380459       1449        375   \n",
       "\n",
       "    attackDamage  armorPenetrationPercent  lifesteal  abilityPower  \\\n",
       "0            166                        0          4             0   \n",
       "2            139                        0          0             0   \n",
       "8             76                        0          0             9   \n",
       "9            101                        0          0             0   \n",
       "13            72                        0          0           144   \n",
       "\n",
       "    resourceValue  magicPenetrationFlat  attackSpeed  currentHealth  armor  \\\n",
       "0             112                     0          190            752     51   \n",
       "2             599                     0          131           1215     86   \n",
       "8               0                     0          107            520    122   \n",
       "9               0                     0          117              0    180   \n",
       "13           1008                     0          129              0     71   \n",
       "\n",
       "    magicPenetrationPercent  resourceMax  resourceRegenRate  \n",
       "0                         0          590                 17  \n",
       "2                         0          599                 23  \n",
       "8                         0            0                  0  \n",
       "9                         0            0                  0  \n",
       "13                        0         1232                113  "
      ]
     },
     "execution_count": 34,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "y_test = test[label]  # values to predict\n",
    "test_data_nolabel = test.drop(columns=[label])  # delete label column to prove we're not cheating, also drop identifier column\n",
    "test_data_nolabel.head(5)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 35,
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-12-02T06:59:18.437876Z",
     "start_time": "2021-12-02T06:58:24.229814Z"
    }
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Predictions:  \n",
      " 0         1\n",
      "2         0\n",
      "8         1\n",
      "9         0\n",
      "13        1\n",
      "         ..\n",
      "499986    1\n",
      "499990    1\n",
      "499993    0\n",
      "499995    0\n",
      "499999    0\n",
      "Name: winner, Length: 100000, dtype: int64\n"
     ]
    }
   ],
   "source": [
    "predictor = TabularPredictor.load(save_path)\n",
    "\n",
    "y_pred = predictor.predict(test_data_nolabel)\n",
    "print(\"Predictions:  \\n\", y_pred)\n",
    "#perf = predictor.evaluate_predictions(y_true=y_test, y_pred=y_pred, auxiliary_metrics=True)\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 36,
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-12-02T07:13:32.963745Z",
     "start_time": "2021-12-02T06:59:18.440497Z"
    }
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "                  model  score_test  score_val  pred_time_test  pred_time_val    fit_time  pred_time_test_marginal  pred_time_val_marginal  fit_time_marginal  stack_level  can_infer  fit_order\n",
      "0   WeightedEnsemble_L2     0.66544   0.689078       12.998381       1.530008  866.161298                 0.006004                0.006177           1.356416            2       True         14\n",
      "1      RandomForestGini     0.66069   0.676831        2.016773       0.315675   22.368041                 2.016773                0.315675          22.368041            1       True          5\n",
      "2      RandomForestEntr     0.66011   0.677081        1.908432       0.314932   24.854358                 1.908432                0.314932          24.854358            1       True          6\n",
      "3        ExtraTreesGini     0.65994   0.669833        4.162963       0.314386   11.347579                 4.162963                0.314386          11.347579            1       True          8\n",
      "4        ExtraTreesEntr     0.65928   0.673332        3.386951       0.313787   11.595320                 3.386951                0.313787          11.595320            1       True          9\n",
      "5        NeuralNetMXNet     0.64286   0.648588        1.480003       0.242218  793.445433                 1.480003                0.242218         793.445433            1       True         12\n",
      "6         LightGBMLarge     0.60645   0.622844        0.079303       0.015620    3.809432                 0.079303                0.015620           3.809432            1       True         13\n",
      "7       NeuralNetFastAI     0.60542   0.615846        7.990198       0.051421  325.652130                 7.990198                0.051421         325.652130            1       True         10\n",
      "8               XGBoost     0.59687   0.614096        0.070154       0.033291    0.968276                 0.070154                0.033291           0.968276            1       True         11\n",
      "9              LightGBM     0.56626   0.575606        0.022063       0.011376    0.475452                 0.022063                0.011376           0.475452            1       True          4\n",
      "10           LightGBMXT     0.56100   0.572107        0.015192       0.011457    0.718697                 0.015192                0.011457           0.718697            1       True          3\n",
      "11             CatBoost     0.55881   0.565859        0.010589       0.009640    0.813448                 0.010589                0.009640           0.813448            1       True          7\n",
      "12       KNeighborsUnif     0.53039   0.534116      934.033610      40.197675    0.079255               934.033610               40.197675           0.079255            1       True          1\n",
      "13       KNeighborsDist     0.53001   0.532617      955.057964      39.491652    0.077697               955.057964               39.491652           0.077697            1       True          2\n"
     ]
    },
    {
     "data": {
      "text/html": [
       "<div>\n",
       "<style scoped>\n",
       "    .dataframe tbody tr th:only-of-type {\n",
       "        vertical-align: middle;\n",
       "    }\n",
       "\n",
       "    .dataframe tbody tr th {\n",
       "        vertical-align: top;\n",
       "    }\n",
       "\n",
       "    .dataframe thead th {\n",
       "        text-align: right;\n",
       "    }\n",
       "</style>\n",
       "<table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>model</th>\n",
       "      <th>score_test</th>\n",
       "      <th>score_val</th>\n",
       "      <th>pred_time_test</th>\n",
       "      <th>pred_time_val</th>\n",
       "      <th>fit_time</th>\n",
       "      <th>pred_time_test_marginal</th>\n",
       "      <th>pred_time_val_marginal</th>\n",
       "      <th>fit_time_marginal</th>\n",
       "      <th>stack_level</th>\n",
       "      <th>can_infer</th>\n",
       "      <th>fit_order</th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>0</th>\n",
       "      <td>WeightedEnsemble_L2</td>\n",
       "      <td>0.66544</td>\n",
       "      <td>0.689078</td>\n",
       "      <td>12.998381</td>\n",
       "      <td>1.530008</td>\n",
       "      <td>866.161298</td>\n",
       "      <td>0.006004</td>\n",
       "      <td>0.006177</td>\n",
       "      <td>1.356416</td>\n",
       "      <td>2</td>\n",
       "      <td>True</td>\n",
       "      <td>14</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1</th>\n",
       "      <td>RandomForestGini</td>\n",
       "      <td>0.66069</td>\n",
       "      <td>0.676831</td>\n",
       "      <td>2.016773</td>\n",
       "      <td>0.315675</td>\n",
       "      <td>22.368041</td>\n",
       "      <td>2.016773</td>\n",
       "      <td>0.315675</td>\n",
       "      <td>22.368041</td>\n",
       "      <td>1</td>\n",
       "      <td>True</td>\n",
       "      <td>5</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2</th>\n",
       "      <td>RandomForestEntr</td>\n",
       "      <td>0.66011</td>\n",
       "      <td>0.677081</td>\n",
       "      <td>1.908432</td>\n",
       "      <td>0.314932</td>\n",
       "      <td>24.854358</td>\n",
       "      <td>1.908432</td>\n",
       "      <td>0.314932</td>\n",
       "      <td>24.854358</td>\n",
       "      <td>1</td>\n",
       "      <td>True</td>\n",
       "      <td>6</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>3</th>\n",
       "      <td>ExtraTreesGini</td>\n",
       "      <td>0.65994</td>\n",
       "      <td>0.669833</td>\n",
       "      <td>4.162963</td>\n",
       "      <td>0.314386</td>\n",
       "      <td>11.347579</td>\n",
       "      <td>4.162963</td>\n",
       "      <td>0.314386</td>\n",
       "      <td>11.347579</td>\n",
       "      <td>1</td>\n",
       "      <td>True</td>\n",
       "      <td>8</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>4</th>\n",
       "      <td>ExtraTreesEntr</td>\n",
       "      <td>0.65928</td>\n",
       "      <td>0.673332</td>\n",
       "      <td>3.386951</td>\n",
       "      <td>0.313787</td>\n",
       "      <td>11.595320</td>\n",
       "      <td>3.386951</td>\n",
       "      <td>0.313787</td>\n",
       "      <td>11.595320</td>\n",
       "      <td>1</td>\n",
       "      <td>True</td>\n",
       "      <td>9</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>5</th>\n",
       "      <td>NeuralNetMXNet</td>\n",
       "      <td>0.64286</td>\n",
       "      <td>0.648588</td>\n",
       "      <td>1.480003</td>\n",
       "      <td>0.242218</td>\n",
       "      <td>793.445433</td>\n",
       "      <td>1.480003</td>\n",
       "      <td>0.242218</td>\n",
       "      <td>793.445433</td>\n",
       "      <td>1</td>\n",
       "      <td>True</td>\n",
       "      <td>12</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>6</th>\n",
       "      <td>LightGBMLarge</td>\n",
       "      <td>0.60645</td>\n",
       "      <td>0.622844</td>\n",
       "      <td>0.079303</td>\n",
       "      <td>0.015620</td>\n",
       "      <td>3.809432</td>\n",
       "      <td>0.079303</td>\n",
       "      <td>0.015620</td>\n",
       "      <td>3.809432</td>\n",
       "      <td>1</td>\n",
       "      <td>True</td>\n",
       "      <td>13</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>7</th>\n",
       "      <td>NeuralNetFastAI</td>\n",
       "      <td>0.60542</td>\n",
       "      <td>0.615846</td>\n",
       "      <td>7.990198</td>\n",
       "      <td>0.051421</td>\n",
       "      <td>325.652130</td>\n",
       "      <td>7.990198</td>\n",
       "      <td>0.051421</td>\n",
       "      <td>325.652130</td>\n",
       "      <td>1</td>\n",
       "      <td>True</td>\n",
       "      <td>10</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>8</th>\n",
       "      <td>XGBoost</td>\n",
       "      <td>0.59687</td>\n",
       "      <td>0.614096</td>\n",
       "      <td>0.070154</td>\n",
       "      <td>0.033291</td>\n",
       "      <td>0.968276</td>\n",
       "      <td>0.070154</td>\n",
       "      <td>0.033291</td>\n",
       "      <td>0.968276</td>\n",
       "      <td>1</td>\n",
       "      <td>True</td>\n",
       "      <td>11</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>9</th>\n",
       "      <td>LightGBM</td>\n",
       "      <td>0.56626</td>\n",
       "      <td>0.575606</td>\n",
       "      <td>0.022063</td>\n",
       "      <td>0.011376</td>\n",
       "      <td>0.475452</td>\n",
       "      <td>0.022063</td>\n",
       "      <td>0.011376</td>\n",
       "      <td>0.475452</td>\n",
       "      <td>1</td>\n",
       "      <td>True</td>\n",
       "      <td>4</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>10</th>\n",
       "      <td>LightGBMXT</td>\n",
       "      <td>0.56100</td>\n",
       "      <td>0.572107</td>\n",
       "      <td>0.015192</td>\n",
       "      <td>0.011457</td>\n",
       "      <td>0.718697</td>\n",
       "      <td>0.015192</td>\n",
       "      <td>0.011457</td>\n",
       "      <td>0.718697</td>\n",
       "      <td>1</td>\n",
       "      <td>True</td>\n",
       "      <td>3</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>11</th>\n",
       "      <td>CatBoost</td>\n",
       "      <td>0.55881</td>\n",
       "      <td>0.565859</td>\n",
       "      <td>0.010589</td>\n",
       "      <td>0.009640</td>\n",
       "      <td>0.813448</td>\n",
       "      <td>0.010589</td>\n",
       "      <td>0.009640</td>\n",
       "      <td>0.813448</td>\n",
       "      <td>1</td>\n",
       "      <td>True</td>\n",
       "      <td>7</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>12</th>\n",
       "      <td>KNeighborsUnif</td>\n",
       "      <td>0.53039</td>\n",
       "      <td>0.534116</td>\n",
       "      <td>934.033610</td>\n",
       "      <td>40.197675</td>\n",
       "      <td>0.079255</td>\n",
       "      <td>934.033610</td>\n",
       "      <td>40.197675</td>\n",
       "      <td>0.079255</td>\n",
       "      <td>1</td>\n",
       "      <td>True</td>\n",
       "      <td>1</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>13</th>\n",
       "      <td>KNeighborsDist</td>\n",
       "      <td>0.53001</td>\n",
       "      <td>0.532617</td>\n",
       "      <td>955.057964</td>\n",
       "      <td>39.491652</td>\n",
       "      <td>0.077697</td>\n",
       "      <td>955.057964</td>\n",
       "      <td>39.491652</td>\n",
       "      <td>0.077697</td>\n",
       "      <td>1</td>\n",
       "      <td>True</td>\n",
       "      <td>2</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table>\n",
       "</div>"
      ],
      "text/plain": [
       "                  model  score_test  score_val  pred_time_test  pred_time_val  \\\n",
       "0   WeightedEnsemble_L2     0.66544   0.689078       12.998381       1.530008   \n",
       "1      RandomForestGini     0.66069   0.676831        2.016773       0.315675   \n",
       "2      RandomForestEntr     0.66011   0.677081        1.908432       0.314932   \n",
       "3        ExtraTreesGini     0.65994   0.669833        4.162963       0.314386   \n",
       "4        ExtraTreesEntr     0.65928   0.673332        3.386951       0.313787   \n",
       "5        NeuralNetMXNet     0.64286   0.648588        1.480003       0.242218   \n",
       "6         LightGBMLarge     0.60645   0.622844        0.079303       0.015620   \n",
       "7       NeuralNetFastAI     0.60542   0.615846        7.990198       0.051421   \n",
       "8               XGBoost     0.59687   0.614096        0.070154       0.033291   \n",
       "9              LightGBM     0.56626   0.575606        0.022063       0.011376   \n",
       "10           LightGBMXT     0.56100   0.572107        0.015192       0.011457   \n",
       "11             CatBoost     0.55881   0.565859        0.010589       0.009640   \n",
       "12       KNeighborsUnif     0.53039   0.534116      934.033610      40.197675   \n",
       "13       KNeighborsDist     0.53001   0.532617      955.057964      39.491652   \n",
       "\n",
       "      fit_time  pred_time_test_marginal  pred_time_val_marginal  \\\n",
       "0   866.161298                 0.006004                0.006177   \n",
       "1    22.368041                 2.016773                0.315675   \n",
       "2    24.854358                 1.908432                0.314932   \n",
       "3    11.347579                 4.162963                0.314386   \n",
       "4    11.595320                 3.386951                0.313787   \n",
       "5   793.445433                 1.480003                0.242218   \n",
       "6     3.809432                 0.079303                0.015620   \n",
       "7   325.652130                 7.990198                0.051421   \n",
       "8     0.968276                 0.070154                0.033291   \n",
       "9     0.475452                 0.022063                0.011376   \n",
       "10    0.718697                 0.015192                0.011457   \n",
       "11    0.813448                 0.010589                0.009640   \n",
       "12    0.079255               934.033610               40.197675   \n",
       "13    0.077697               955.057964               39.491652   \n",
       "\n",
       "    fit_time_marginal  stack_level  can_infer  fit_order  \n",
       "0            1.356416            2       True         14  \n",
       "1           22.368041            1       True          5  \n",
       "2           24.854358            1       True          6  \n",
       "3           11.347579            1       True          8  \n",
       "4           11.595320            1       True          9  \n",
       "5          793.445433            1       True         12  \n",
       "6            3.809432            1       True         13  \n",
       "7          325.652130            1       True         10  \n",
       "8            0.968276            1       True         11  \n",
       "9            0.475452            1       True          4  \n",
       "10           0.718697            1       True          3  \n",
       "11           0.813448            1       True          7  \n",
       "12           0.079255            1       True          1  \n",
       "13           0.077697            1       True          2  "
      ]
     },
     "execution_count": 36,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "predictor.leaderboard(test, silent=False)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 37,
   "metadata": {
    "ExecuteTime": {
     "end_time": "2021-12-02T07:16:02.649363Z",
     "start_time": "2021-12-02T07:13:32.965482Z"
    }
   },
   "outputs": [
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "Computing feature importance via permutation shuffling for 18 features using 1000 rows with 3 shuffle sets...\n",
      "\t549.57s\t= Expected runtime (183.19s per shuffle set)\n",
      "\t62.24s\t= Actual runtime (Completed 3 of 3 shuffle sets)\n"
     ]
    },
    {
     "data": {
      "text/html": [
       "<div>\n",
       "<style scoped>\n",
       "    .dataframe tbody tr th:only-of-type {\n",
       "        vertical-align: middle;\n",
       "    }\n",
       "\n",
       "    .dataframe tbody tr th {\n",
       "        vertical-align: top;\n",
       "    }\n",
       "\n",
       "    .dataframe thead th {\n",
       "        text-align: right;\n",
       "    }\n",
       "</style>\n",
       "<table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>importance</th>\n",
       "      <th>stddev</th>\n",
       "      <th>p_value</th>\n",
       "      <th>n</th>\n",
       "      <th>p99_high</th>\n",
       "      <th>p99_low</th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>timestamp</th>\n",
       "      <td>0.115667</td>\n",
       "      <td>0.015044</td>\n",
       "      <td>0.002796</td>\n",
       "      <td>3</td>\n",
       "      <td>0.201873</td>\n",
       "      <td>0.029461</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>attackDamage</th>\n",
       "      <td>0.090333</td>\n",
       "      <td>0.018610</td>\n",
       "      <td>0.006927</td>\n",
       "      <td>3</td>\n",
       "      <td>0.196971</td>\n",
       "      <td>-0.016304</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>abilityPower</th>\n",
       "      <td>0.069000</td>\n",
       "      <td>0.009000</td>\n",
       "      <td>0.002812</td>\n",
       "      <td>3</td>\n",
       "      <td>0.120571</td>\n",
       "      <td>0.017429</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>maxHealth</th>\n",
       "      <td>0.044667</td>\n",
       "      <td>0.025541</td>\n",
       "      <td>0.046946</td>\n",
       "      <td>3</td>\n",
       "      <td>0.191018</td>\n",
       "      <td>-0.101685</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>armor</th>\n",
       "      <td>0.040667</td>\n",
       "      <td>0.021502</td>\n",
       "      <td>0.040951</td>\n",
       "      <td>3</td>\n",
       "      <td>0.163875</td>\n",
       "      <td>-0.082542</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>resourceMax</th>\n",
       "      <td>0.038667</td>\n",
       "      <td>0.009713</td>\n",
       "      <td>0.010195</td>\n",
       "      <td>3</td>\n",
       "      <td>0.094321</td>\n",
       "      <td>-0.016987</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>magicResist</th>\n",
       "      <td>0.037333</td>\n",
       "      <td>0.013650</td>\n",
       "      <td>0.020895</td>\n",
       "      <td>3</td>\n",
       "      <td>0.115552</td>\n",
       "      <td>-0.040885</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>resourceValue</th>\n",
       "      <td>0.030667</td>\n",
       "      <td>0.024028</td>\n",
       "      <td>0.078814</td>\n",
       "      <td>3</td>\n",
       "      <td>0.168348</td>\n",
       "      <td>-0.107015</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>attackSpeed</th>\n",
       "      <td>0.028667</td>\n",
       "      <td>0.022301</td>\n",
       "      <td>0.077944</td>\n",
       "      <td>3</td>\n",
       "      <td>0.156454</td>\n",
       "      <td>-0.099120</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>resourceRegenRate</th>\n",
       "      <td>0.027333</td>\n",
       "      <td>0.015503</td>\n",
       "      <td>0.046289</td>\n",
       "      <td>3</td>\n",
       "      <td>0.116165</td>\n",
       "      <td>-0.061499</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>moveSpeed</th>\n",
       "      <td>0.018333</td>\n",
       "      <td>0.017039</td>\n",
       "      <td>0.101700</td>\n",
       "      <td>3</td>\n",
       "      <td>0.115970</td>\n",
       "      <td>-0.079303</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>currentHealth</th>\n",
       "      <td>0.013000</td>\n",
       "      <td>0.012166</td>\n",
       "      <td>0.102702</td>\n",
       "      <td>3</td>\n",
       "      <td>0.082710</td>\n",
       "      <td>-0.056710</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>healthRegenRate</th>\n",
       "      <td>0.011333</td>\n",
       "      <td>0.013051</td>\n",
       "      <td>0.135733</td>\n",
       "      <td>3</td>\n",
       "      <td>0.086118</td>\n",
       "      <td>-0.063451</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>lifesteal</th>\n",
       "      <td>0.006667</td>\n",
       "      <td>0.009018</td>\n",
       "      <td>0.164422</td>\n",
       "      <td>3</td>\n",
       "      <td>0.058344</td>\n",
       "      <td>-0.045010</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>armorPenetrationPercent</th>\n",
       "      <td>0.006000</td>\n",
       "      <td>0.002000</td>\n",
       "      <td>0.017549</td>\n",
       "      <td>3</td>\n",
       "      <td>0.017460</td>\n",
       "      <td>-0.005460</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>magicPenetrationFlat</th>\n",
       "      <td>0.004333</td>\n",
       "      <td>0.003512</td>\n",
       "      <td>0.083025</td>\n",
       "      <td>3</td>\n",
       "      <td>0.024457</td>\n",
       "      <td>-0.015790</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>magicPenetrationPercent</th>\n",
       "      <td>0.002333</td>\n",
       "      <td>0.001528</td>\n",
       "      <td>0.059041</td>\n",
       "      <td>3</td>\n",
       "      <td>0.011086</td>\n",
       "      <td>-0.006420</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>spellVamp</th>\n",
       "      <td>-0.000667</td>\n",
       "      <td>0.000577</td>\n",
       "      <td>0.908248</td>\n",
       "      <td>3</td>\n",
       "      <td>0.002642</td>\n",
       "      <td>-0.003975</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table>\n",
       "</div>"
      ],
      "text/plain": [
       "                         importance    stddev   p_value  n  p99_high   p99_low\n",
       "timestamp                  0.115667  0.015044  0.002796  3  0.201873  0.029461\n",
       "attackDamage               0.090333  0.018610  0.006927  3  0.196971 -0.016304\n",
       "abilityPower               0.069000  0.009000  0.002812  3  0.120571  0.017429\n",
       "maxHealth                  0.044667  0.025541  0.046946  3  0.191018 -0.101685\n",
       "armor                      0.040667  0.021502  0.040951  3  0.163875 -0.082542\n",
       "resourceMax                0.038667  0.009713  0.010195  3  0.094321 -0.016987\n",
       "magicResist                0.037333  0.013650  0.020895  3  0.115552 -0.040885\n",
       "resourceValue              0.030667  0.024028  0.078814  3  0.168348 -0.107015\n",
       "attackSpeed                0.028667  0.022301  0.077944  3  0.156454 -0.099120\n",
       "resourceRegenRate          0.027333  0.015503  0.046289  3  0.116165 -0.061499\n",
       "moveSpeed                  0.018333  0.017039  0.101700  3  0.115970 -0.079303\n",
       "currentHealth              0.013000  0.012166  0.102702  3  0.082710 -0.056710\n",
       "healthRegenRate            0.011333  0.013051  0.135733  3  0.086118 -0.063451\n",
       "lifesteal                  0.006667  0.009018  0.164422  3  0.058344 -0.045010\n",
       "armorPenetrationPercent    0.006000  0.002000  0.017549  3  0.017460 -0.005460\n",
       "magicPenetrationFlat       0.004333  0.003512  0.083025  3  0.024457 -0.015790\n",
       "magicPenetrationPercent    0.002333  0.001528  0.059041  3  0.011086 -0.006420\n",
       "spellVamp                 -0.000667  0.000577  0.908248  3  0.002642 -0.003975"
      ]
     },
     "execution_count": 37,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "predictor.feature_importance(test)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 38,
   "metadata": {},
   "outputs": [],
   "source": [
    "data = [91, 35, 0, 1080321, 2204, 390, 225, 0, 10, 0, 672, 0, 220, 0, 94, 0, 1047, 33]\n",
    "\n",
    "test_d = pd.DataFrame([data], columns=['magicResist', 'healthRegenRate', 'spellVamp', 'timestamp', 'maxHealth', 'moveSpeed', 'attackDamage', 'armorPenetrationPercent', 'lifesteal', 'abilityPower', 'resourceValue', 'magicPenetrationFlat', 'attackSpeed', 'currentHealth', 'armor', 'magicPenetrationPercent', 'resourceMax', 'resourceRegenRate'])"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 39,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "0    1\n",
       "Name: winner, dtype: int64"
      ]
     },
     "execution_count": 39,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "predictor.predict(test_d)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 40,
   "metadata": {},
   "outputs": [],
   "source": [
    "pred_probs = predictor.predict_proba(test_d)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 41,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "          0         1\n",
      "0  0.205442  0.794558\n"
     ]
    }
   ],
   "source": [
    "print(pred_probs)"
   ]
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "miniconda",
   "language": "python",
   "name": "miniconda"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.7.11"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 4
}
